pub struct TokenClient<'a> {
pub env: Env,
pub address: Address,
/* private fields */
}Expand description
TokenClient is a client for calling the contract defined in “Token”.
Fields
env: Envaddress: AddressImplementations
Sourceimpl<'a> TokenClient<'a>
impl<'a> TokenClient<'a>
Sourcepub fn allowance(&self, from: &Address, spender: &Address) -> i128
pub fn allowance(&self, from: &Address, spender: &Address) -> i128
Returns the allowance for spender to transfer from from.
Arguments
from- The address holding the balance of tokens to be drawn from.spender- The address spending the tokens held byfrom.
Sourcepub fn try_allowance(
&self,
from: &Address,
spender: &Address,
) -> Result<Result<i128, <i128 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_allowance( &self, from: &Address, spender: &Address, ) -> Result<Result<i128, <i128 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Returns the allowance for spender to transfer from from.
Arguments
from- The address holding the balance of tokens to be drawn from.spender- The address spending the tokens held byfrom.
Sourcepub fn approve(
&self,
from: &Address,
spender: &Address,
amount: &i128,
live_until_ledger: &u32,
)
pub fn approve( &self, from: &Address, spender: &Address, amount: &i128, live_until_ledger: &u32, )
Set the allowance by amount for spender to transfer/burn from
from. Overrides any existing allowance set between spender and from.
Arguments
from- The address holding the balance of tokens to be drawn from.spender- The address being authorized to spend the tokens held byfrom.amount- The tokens to be made available tospender.live_until_ledger- The ledger number where this allowance expires. Cannot be less than the current ledger number unless the amount is being set to 0. An expired entry (where live_until_ledger < the current ledger number) should be treated as a 0 amount allowance.
Events
Emits an event with topics ["approve", from: Address, spender: Address], data = [amount: i128, live_until_ledger: u32]
Emits an event with:
- topics -
["approve", from: Address, spender: Address] - data -
[amount: i128, live_until_ledger: u32]
Sourcepub fn try_approve(
&self,
from: &Address,
spender: &Address,
amount: &i128,
live_until_ledger: &u32,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_approve( &self, from: &Address, spender: &Address, amount: &i128, live_until_ledger: &u32, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Set the allowance by amount for spender to transfer/burn from
from. Overrides any existing allowance set between spender and from.
Arguments
from- The address holding the balance of tokens to be drawn from.spender- The address being authorized to spend the tokens held byfrom.amount- The tokens to be made available tospender.live_until_ledger- The ledger number where this allowance expires. Cannot be less than the current ledger number unless the amount is being set to 0. An expired entry (where live_until_ledger < the current ledger number) should be treated as a 0 amount allowance.
Events
Emits an event with topics ["approve", from: Address, spender: Address], data = [amount: i128, live_until_ledger: u32]
Emits an event with:
- topics -
["approve", from: Address, spender: Address] - data -
[amount: i128, live_until_ledger: u32]
Sourcepub fn balance(&self, id: &Address) -> i128
pub fn balance(&self, id: &Address) -> i128
Returns the balance of id.
Arguments
id- The address for which a balance is being queried. If the address has no existing balance, returns 0.
Sourcepub fn try_balance(
&self,
id: &Address,
) -> Result<Result<i128, <i128 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_balance( &self, id: &Address, ) -> Result<Result<i128, <i128 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Returns the balance of id.
Arguments
id- The address for which a balance is being queried. If the address has no existing balance, returns 0.
Sourcepub fn transfer(&self, from: &Address, to: &Address, amount: &i128)
pub fn transfer(&self, from: &Address, to: &Address, amount: &i128)
Transfer amount from from to to.
Arguments
from- The address holding the balance of tokens which will be withdrawn from.to- The address which will receive the transferred tokens.amount- The amount of tokens to be transferred.
Events
Emits an event with:
- topics -
["transfer", from: Address, to: Address] - data -
[amount: i128]
Sourcepub fn try_transfer(
&self,
from: &Address,
to: &Address,
amount: &i128,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_transfer( &self, from: &Address, to: &Address, amount: &i128, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Transfer amount from from to to.
Arguments
from- The address holding the balance of tokens which will be withdrawn from.to- The address which will receive the transferred tokens.amount- The amount of tokens to be transferred.
Events
Emits an event with:
- topics -
["transfer", from: Address, to: Address] - data -
[amount: i128]
Sourcepub fn transfer_from(
&self,
spender: &Address,
from: &Address,
to: &Address,
amount: &i128,
)
pub fn transfer_from( &self, spender: &Address, from: &Address, to: &Address, amount: &i128, )
Transfer amount from from to to, consuming the allowance of
spender. Authorized by spender (spender.require_auth()).
Arguments
spender- The address authorizing the transfer, and having its allowance consumed during the transfer.from- The address holding the balance of tokens which will be withdrawn from.to- The address which will receive the transferred tokens.amount- The amount of tokens to be transferred.
Events
Emits an event with:
- topics -
["transfer", from: Address, to: Address] - data -
[amount: i128]
Sourcepub fn try_transfer_from(
&self,
spender: &Address,
from: &Address,
to: &Address,
amount: &i128,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_transfer_from( &self, spender: &Address, from: &Address, to: &Address, amount: &i128, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Transfer amount from from to to, consuming the allowance of
spender. Authorized by spender (spender.require_auth()).
Arguments
spender- The address authorizing the transfer, and having its allowance consumed during the transfer.from- The address holding the balance of tokens which will be withdrawn from.to- The address which will receive the transferred tokens.amount- The amount of tokens to be transferred.
Events
Emits an event with:
- topics -
["transfer", from: Address, to: Address] - data -
[amount: i128]
Sourcepub fn try_burn(
&self,
from: &Address,
amount: &i128,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_burn( &self, from: &Address, amount: &i128, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Sourcepub fn burn_from(&self, spender: &Address, from: &Address, amount: &i128)
pub fn burn_from(&self, spender: &Address, from: &Address, amount: &i128)
Burn amount from from, consuming the allowance of spender.
Arguments
spender- The address authorizing the burn, and having its allowance consumed during the burn.from- The address holding the balance of tokens which will be burned from.amount- The amount of tokens to be burned.
Events
Emits an event with:
- topics -
["burn", from: Address] - data -
[amount: i128]
Sourcepub fn try_burn_from(
&self,
spender: &Address,
from: &Address,
amount: &i128,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_burn_from( &self, spender: &Address, from: &Address, amount: &i128, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Burn amount from from, consuming the allowance of spender.
Arguments
spender- The address authorizing the burn, and having its allowance consumed during the burn.from- The address holding the balance of tokens which will be burned from.amount- The amount of tokens to be burned.
Events
Emits an event with:
- topics -
["burn", from: Address] - data -
[amount: i128]
Sourcepub fn decimals(&self) -> u32
pub fn decimals(&self) -> u32
Returns the number of decimals used to represent amounts of this token.
Sourcepub fn try_decimals(
&self,
) -> Result<Result<u32, <u32 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_decimals( &self, ) -> Result<Result<u32, <u32 as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Returns the number of decimals used to represent amounts of this token.
Sourcepub fn try_name(
&self,
) -> Result<Result<String, <String as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_name( &self, ) -> Result<Result<String, <String as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Returns the name for this token.
Sourcepub fn try_symbol(
&self,
) -> Result<Result<String, <String as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_symbol( &self, ) -> Result<Result<String, <String as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Returns the symbol for this token.